import * as React from 'react';
import classNames from 'classnames';
// import './index.less';
import { ConfigProvider, theme } from 'antd';
import { useStyle } from './style';
const clsPrefix = 'osui-highlight-text';
const { useToken } = theme;
const breakWordsByMark = (input, mark, props) => {
    const className = props && props.className || '';
    if (typeof input !== 'string' || typeof mark !== 'string') {
        return input;
    }
    const parts = input.split(new RegExp(`(${mark})`, 'gi'));
    return parts.map((part, index) => {
        if (!part) {
            return null;
        }
        if (part.toLowerCase() === mark.toLowerCase()) {
            return (React.createElement("span", { 
                // eslint-disable-next-line react/no-array-index-key
                key: `${part}-${index}`, ...props, className: classNames(`${clsPrefix}-mark`, className) }, part));
        }
        else {
            return part;
        }
    });
};
const HighlightText = ({ children, mark, markProps, prefixCls: prefixClsIn }) => {
    const [text, setText] = React.useState(children);
    const { getPrefixCls, theme } = React.useContext(ConfigProvider.ConfigContext);
    const cssVar = theme?.cssVar;
    const prefixCls = getPrefixCls('highlightText', prefixClsIn);
    const wrapSSROsui = useStyle(clsPrefix, prefixCls, cssVar);
    const { hashId } = useToken();
    React.useLayoutEffect(() => {
        const requestId = window.requestAnimationFrame(() => {
            setText(breakWordsByMark(children, mark, {
                ...markProps,
                className: classNames(markProps?.className, hashId),
            }));
        });
        return () => {
            window.cancelAnimationFrame(requestId);
        };
    }, 
    // eslint-disable-next-line react-hooks/exhaustive-deps
    [children, mark]);
    return wrapSSROsui(React.createElement(React.Fragment, null, text));
};
export default HighlightText;
//# sourceMappingURL=index.js.map